JasminElementType

Enum JasminElementType 

pub enum JasminElementType {
Show 92 variants Root, Class, Method, Field, Instruction, IdentifierNode, StringNode, NumberNode, ErrorNode, ClassKw, VersionKw, MethodKw, FieldKw, StringKw, SourceFileKw, StackKw, LocalsKw, EndKw, CompiledKw, FromKw, InnerClassKw, NestMembersKw, BootstrapMethodKw, Public, Private, Protected, Static, Super, Final, Abstract, Synchronized, Native, Synthetic, Deprecated, Varargs, Bridge, Enum, Annotation, Strictfp, Interface, Volatile, Transient, ALoad0, ALoad1, ALoad2, ALoad3, ILoad0, ILoad1, ILoad2, ILoad3, Ldc, LdcW, Ldc2W, InvokeSpecial, InvokeVirtual, InvokeStatic, InvokeInterface, InvokeDynamic, GetStatic, PutStatic, GetField, PutField, Return, IReturn, AReturn, LReturn, FReturn, DReturn, Nop, Dup, Pop, New, LeftBrace, RightBrace, LeftParen, RightParen, LeftBracket, RightBracket, Colon, Semicolon, Dot, Comma, Slash, StringLiteral, Number, TypeDescriptor, IdentifierToken, Whitespace, Newline, Comment, Eof, Error,
}
Jasmin element types for the green tree.

Variants



Root

Root node.



Class

Class definition.



Method

Method definition.



Field

Field definition.



Instruction

Instruction.



IdentifierNode

Identifier node.



StringNode

String node.



NumberNode

Number node.



ErrorNode

Error node.



ClassKw

.class keyword.



VersionKw

.version keyword.



MethodKw

.method keyword.



FieldKw

.field keyword.



StringKw

.string keyword.



SourceFileKw

.source keyword.



StackKw

.stack keyword.



LocalsKw

.limit locals keyword.



EndKw

.end keyword.



CompiledKw

compiled keyword.



FromKw

from keyword.



InnerClassKw

.inner keyword.



NestMembersKw

.nest keyword.



BootstrapMethodKw

.bootstrap keyword.



Public

public access flag.



Private

private access flag.



Protected

protected access flag.



Static

static access flag.



Super

super access flag.



Final

final access flag.



Abstract

abstract access flag.



Synchronized

synchronized access flag.



Native

native access flag.



Synthetic

synthetic access flag.



Deprecated

deprecated access flag.



Varargs

varargs access flag.



Bridge

bridge access flag.



Enum

enum keyword.



Annotation

annotation keyword.



Strictfp

strictfp access flag.



Interface

interface keyword.



Volatile

volatile access flag.



Transient

transient access flag.



ALoad0

aload_0 instruction.



ALoad1

aload_1 instruction.



ALoad2

aload_2 instruction.



ALoad3

aload_3 instruction.



ILoad0

iload_0 instruction.



ILoad1

iload_1 instruction.



ILoad2

iload_2 instruction.



ILoad3

iload_3 instruction.



Ldc

ldc instruction.



LdcW

ldc_w instruction.



Ldc2W

ldc2_w instruction.



InvokeSpecial

invokespecial instruction.



InvokeVirtual

invokevirtual instruction.



InvokeStatic

invokestatic instruction.



InvokeInterface

invokeinterface instruction.



InvokeDynamic

invokedynamic instruction.



GetStatic

getstatic instruction.



PutStatic

putstatic instruction.



GetField

getfield instruction.



PutField

putfield instruction.



Return

return instruction.



IReturn

ireturn instruction.



AReturn

areturn instruction.



LReturn

lreturn instruction.



FReturn

freturn instruction.



DReturn

dreturn instruction.



Nop

nop instruction.



Dup

dup instruction.



Pop

pop instruction.



New

new instruction.



LeftBrace

{ token.



RightBrace

} token.



LeftParen

( token.



RightParen

) token.



LeftBracket

[ token.



RightBracket

] token.



Colon

: token.



Semicolon

; token.



Dot

. token.



Comma

, token.



Slash

/ token.



StringLiteral

String literal token.



Number

Number token.



TypeDescriptor

Type descriptor token.



IdentifierToken

Identifier token.



Whitespace

Whitespace token.



Newline

Newline token.



Comment

Comment token.



Eof

EOF token.



Error

Error token.